<?php

/**
 * Load theme updater functions.
 * Action is used so that child themes can easily disable.
 */

function pixeldom_theme_updater()
{
	require (get_template_directory() . '/updater/theme-updater.php');

}

add_action('after_setup_theme', 'pixeldom_theme_updater');
/**
 * Adding Post Format Support.
 */

function pixeldom_post_formats_setup()
{
	add_theme_support('post-formats', array(
		'gallery',
		'quote',
		'video',
		'aside',
		'image',
		'link'
	));
}

add_action('after_setup_theme', 'pixeldom_post_formats_setup');

//////////////////////////////////////////////////////////////////
// Set Content Width
//////////////////////////////////////////////////////////////////
if ( ! isset( $content_width ) )
	$content_width = 940;

	
//////////////////////////////////////////////////////////////////
// Theme set up
//////////////////////////////////////////////////////////////////
add_action( 'after_setup_theme', 'pixeldom_theme_setup' );

if ( !function_exists('pixeldom_theme_setup') ) {

	function pixeldom_theme_setup() {
	
		// Register navigation menu
		register_nav_menus(
			array(
				'main-menu' => 'Primary Menu',
			)
		);
		
		// Localization support
		load_theme_textdomain('pixeldom', get_template_directory() . '/lang');
		
		// Feed Links
		add_theme_support( 'automatic-feed-links' );
		
		// Post formats
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );

		// Post thumbnails
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'full-thumb', 940, 0, true );
		add_image_size( 'slider-thumb', 650, 440, true );
		add_image_size( 'thumb', 440, 294, true );
	
	}

}

//////////////////////////////////////////////////////////////////
// Register & enqueue styles/scripts
//////////////////////////////////////////////////////////////////

add_action( 'wp_enqueue_scripts','pixeldom_load_scripts' );

function pixeldom_load_scripts() {

	// Register scripts and styles
	wp_register_style('sp_style', get_stylesheet_directory_uri() . '/style.css');
	wp_register_style('sp_responsive', get_stylesheet_directory_uri() . '/css/responsive.css');
	wp_register_style('bxslider-css', get_stylesheet_directory_uri() . '/css/jquery.bxslider.css');
	wp_register_style('slicknav-css', get_stylesheet_directory_uri() . '/css/slicknav.css');
	wp_register_style('owl-css', get_stylesheet_directory_uri() . '/css/owl.carousel.css');
	wp_register_style('owl-theme-css', get_stylesheet_directory_uri() . '/css/owl.theme.css');
	wp_register_style('font-awesome', '//netdna.bootstrapcdn.com/font-awesome/4.0.1/css/font-awesome.css');
	
	wp_register_script('sp_scripts', get_template_directory_uri() . '/js/pixeldom.js', 'jquery', '', true);
	wp_register_script('bxslider', get_template_directory_uri() . '/js/jquery.bxslider.min.js', 'jquery', '', true);
	wp_register_script('fitvids', get_template_directory_uri() . '/js/fitvids.js', 'jquery', '', true);
	wp_register_script('slicknav', get_template_directory_uri() . '/js/jquery.slicknav.min.js', 'jquery', '', true);
	wp_register_script('owl', get_template_directory_uri() . '/js/owl.carousel.min.js', 'jquery', '', true);
	wp_register_script('sp_retina', get_template_directory_uri() . '/js/retina.min.js', 'jquery', '', true);
	
	// Enqueue scripts and styles

	wp_enqueue_style('sp_style');
	wp_enqueue_style('sp_responsive');
	wp_enqueue_style('bxslider-css');
	wp_enqueue_style('slicknav-css');
	wp_enqueue_style('owl-css');
	wp_enqueue_style('owl-theme-css');
	wp_enqueue_style('font-awesome');
	wp_enqueue_style('default_headings_font', 'http://fonts.googleapis.com/css?family=Open+Sans:300italic,400italic,700italic,400,700,300&subset=latin,cyrillic-ext');
	wp_enqueue_style('default_body_font', 'http://fonts.googleapis.com/css?family=Crimson+Text:400,700,400italic,700italic');
	
	wp_enqueue_script('jquery');
	wp_enqueue_script('bxslider');
	wp_enqueue_script('fitvids');
	wp_enqueue_script('slicknav');
	wp_enqueue_script('owl');
	wp_enqueue_script('sp_retina');
	wp_enqueue_script('sp_scripts');
	
	if (is_singular() && get_option('thread_comments'))	wp_enqueue_script('comment-reply');
	
}

//////////////////////////////////////////////////////////////////
// Include files
//////////////////////////////////////////////////////////////////

// Theme Options
include('functions/customizer/sp_custom_controller.php');
include('functions/customizer/sp_customizer_settings.php');
include('functions/customizer/sp_customizer_style.php');


//////////////////////////////////////////////////////////////////
// Register footer widgets
//////////////////////////////////////////////////////////////////
if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'name' => 'Sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));

     register_sidebar(array(
		'id' => 'index-ad',
		'name' => 'index ad',
		'description' => 'Paste 728x90 ad code here to place your ads after the 1st & 3rd post on home page and archive/category pages. Leave widget title empty.',
		'before_widget' => '<li class="indexad">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));

	register_sidebar(array(
		'id' => 'before-post-ad',
		'name' => 'before post ad',
		'description' => 'Paste ad code here to place your ad before the post, right under the title. Leave widget title empty.',
		'before_widget' => '<div class="before-post-ad">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));

	register_sidebar(array(
		'id' => 'after-post-ad',
		'name' => 'after post ad',
		'description' => 'Paste ad code here to place your ad after the post. Leave widget title empty.',
		'before_widget' => '<div class="after-post-ad">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));

	register_sidebar(array(
		'id' => 'post-wrap-ad',
		'name' => 'post wrap ad',
		'description' => 'Paste ad code here to put ad wrapped to the right of the first paragraph in your posts. Leave widget title empty.',
		'before_widget' => '<div class="post-wrap-ad">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="widgettitle"><span>',
		'after_title' => '</span></h3>'
	));

}



//////////////////////////////////////////////////////////////////
// PAGINATION
//////////////////////////////////////////////////////////////////
function pixeldom_pagination() {
	
	?>
	
	<div class="pagination">

		<div class="older"><?php next_posts_link(__( 'Older Posts <i class="fa fa-angle-double-right"></i>', 'pixeldom')); ?></div>
		<div class="newer"><?php previous_posts_link(__( '<i class="fa fa-angle-double-left"></i> Newer Posts', 'pixeldom')); ?></div>
		
	</div>
					
	<?php
	
}



//////////////////////////////////////////////////////////////////
// COMMENTS LAYOUT
//////////////////////////////////////////////////////////////////

	function pixeldom_comments($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
			
			<div class="thecomment">
						
				<div class="author-img">
					<?php echo get_avatar($comment,$args['avatar_size']); ?>
				</div>
				
				<div class="comment-text">
					<span class="reply">
						<?php comment_reply_link(array_merge( $args, array('reply_text' => __('Reply', 'manna'), 'depth' => $depth, 'max_depth' => $args['max_depth'])), $comment->comment_ID); ?>
						<?php edit_comment_link(__('Edit', 'manna')); ?>
					</span>
					<span class="author"><?php echo get_comment_author_link(); ?></span>
					<span class="date"><?php printf(__('%1$s at %2$s', 'manna'), get_comment_date(),  get_comment_time()) ?></span>
					<?php if ($comment->comment_approved == '0') : ?>
						<em><i class="icon-info-sign"></i> <?php _e('Comment awaiting approval', 'manna'); ?></em>
						<br />
					<?php endif; ?>
					<?php comment_text(); ?>
				</div>
						
			</div>
			
			
		</li>

		<?php 
	}


//////////////////////////////////////////////////////////////////
// AUTHOR SOCIAL LINKS
//////////////////////////////////////////////////////////////////
function pixeldom_contactmethods( $contactmethods ) {

	$contactmethods['twitter']   = 'Twitter Username';
	$contactmethods['facebook']  = 'Facebook Username';
	$contactmethods['google']    = 'Google Plus Username';
	$contactmethods['tumblr']    = 'Tumblr Username';
	$contactmethods['instagram'] = 'Instagram Username';
	$contactmethods['pinterest'] = 'Pinterest Username';

	return $contactmethods;
}
add_filter('user_contactmethods','pixeldom_contactmethods',10,1);

//////////////////////////////////////////////////////////////////
// EXCLUDE FEATURED CATEGORY
//////////////////////////////////////////////////////////////////

function sp_category($separator) {
	
	if(get_theme_mod( 'sp_featured_cat_hide' ) == true) {
		
		$excluded_cat = get_theme_mod('sp_featured_cat');
		
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($category->cat_ID != $excluded_cat) {
				if ($first_time == 1) {
					echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "pixeldom" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
					$first_time = 0;
				} else {
					echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "pixeldom" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
				}
			}
		}
	
	} else {
		
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($first_time == 1) {
				echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "pixeldom" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
				$first_time = 0;
			} else {
				echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "pixeldom" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
			}
		}
	
	}
}

//////////////////////////////////////////////////////////////////
// THE EXCERPT
//////////////////////////////////////////////////////////////////
function custom_excerpt_length( $length ) {
	return 19;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

function new_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'new_excerpt_more' );